MINOR: mux: Unlink ALPN and multiplexers to rather speak of mux protocols

Multiplexers are not necessarily associated to an ALPN. ALPN is a TLS extension,
so it is not always defined or used. Instead, we now rather speak of
multiplexer's protocols. So in this patch, there are no significative changes,
some structures and functions are just renamed.
diff --git a/include/proto/connection.h b/include/proto/connection.h
index 580ae9a..4e54bcf 100644
--- a/include/proto/connection.h
+++ b/include/proto/connection.h
@@ -34,7 +34,7 @@
 extern struct pool_head *pool_head_connection;
 extern struct pool_head *pool_head_connstream;
 extern struct xprt_ops *registered_xprt[XPRT_ENTRIES];
-extern struct alpn_mux_list alpn_mux_list;
+extern struct mux_proto_list mux_proto_list;
 
 /* perform minimal intializations, report 0 in case of error, 1 if OK. */
 int init_connection();
@@ -949,14 +949,14 @@
 	return conn->xprt->get_alpn(conn, str, len);
 }
 
-/* registers alpn mux list <list>. Modifies the list element! */
-static inline void alpn_register_mux(struct alpn_mux_list *list)
+/* registers proto mux list <list>. Modifies the list element! */
+static inline void register_mux_proto(struct mux_proto_list *list)
 {
-	LIST_ADDQ(&alpn_mux_list.list, &list->list);
+	LIST_ADDQ(&mux_proto_list.list, &list->list);
 }
 
-/* unregisters alpn mux list <list> */
-static inline void alpn_unregister_mux(struct alpn_mux_list *list)
+/* unregisters proto mux list <list> */
+static inline void unregister_mux_proto(struct mux_proto_list *list)
 {
 	LIST_DEL(&list->list);
 	LIST_INIT(&list->list);
@@ -970,12 +970,12 @@
  */
 static inline const struct mux_ops *alpn_get_mux(const struct ist token, int http_mode)
 {
-	struct alpn_mux_list *item;
+	struct mux_proto_list *item;
 	const struct mux_ops *fallback = NULL;
 
 	http_mode = 1 << !!http_mode;
 
-	list_for_each_entry(item, &alpn_mux_list.list, list) {
+	list_for_each_entry(item, &mux_proto_list.list, list) {
 		if (!(item->mode & http_mode))
 			continue;
 		if (isteq(token, item->token))